
# ----------------------- groupedstats -----------------------------------

#' @export
#' @importFrom groupedstats specify_decimal_p
groupedstats::specify_decimal_p

#' @export
#' @importFrom groupedstats signif_column
groupedstats::signif_column

#' @export
#' @importFrom groupedstats set_cwd
groupedstats::set_cwd

# ----------------------- pairwiseComparisons --------------------------------

#' @export
#' @importFrom pairwiseComparisons pairwise_p
pairwiseComparisons::pairwise_p

#' @export
#' @importFrom pairwiseComparisons pairwise_comparisons
pairwiseComparisons::pairwise_comparisons

# ----------------------- tidyverse -------------------------------------

#' @export
#' @importFrom broomExtra "%>%"
broomExtra::`%>%`

#' @export
#' @importFrom broomExtra "%<>%"
broomExtra::`%<>%`

#' @export
#' @importFrom broomExtra "%$%"
broomExtra::`%$%`

#' @export
#' @importFrom rlang "%||%"
rlang::`%||%`

#' @export
#' @importFrom rlang "%|%"
rlang::`%|%`

#' @export
#' @importFrom tibble tibble
tibble::tibble

#' @export
#' @importFrom tibble as_tibble
tibble::as_tibble
